@@ -1,6 +1,6 @@
 test_that("quick_df()", {
-  expect_error(quick_df(1L), class = "quickDfInputError")
-  expect_error(quick_df(list(a = 1:2, b = 1:3)), class = "quickDfListError")
+  expect_error(quick_df(1L), class = "fuj:quickDfInputError")
+  expect_error(quick_df(list(a = 1:2, b = 1:3)), class = "fuj:quickDfListError")
 
   expect_identical(
     quick_df(list(a = NULL)),
